==> zeroc-icee_1.1.0.orig.tar.gz: IceE-1.1.0/test/IceE/location/TestI.h <==
// **********************************************************************
//
// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
//
// This copy of Ice-E is licensed to you under the terms described in the
// ICEE_LICENSE file included in this distribution.
//
// **********************************************************************

#ifndef TEST_I_H
#define TEST_I_H

#include <IceE/Config.h>

#ifdef ICEE_HAS_LOCATOR

#include <Test.h>
#include <vector>
#include <ServerLocator.h>

class ServerManagerI : public Test::ServerManager
{
public:

    ServerManagerI(const Ice::ObjectAdapterPtr&, const ServerLocatorRegistryPtr&, const Ice::PropertiesPtr&);
    
    virtual void startServer(const Ice::Current&);
    virtual void shutdown(const Ice::Current&);

private:

    Ice::ObjectAdapterPtr _adapter;
    ServerLocatorRegistryPtr _registry;
    Ice::PropertiesPtr _properties;
    std::vector<Ice::CommunicatorPtr> _communicators;
};

class HelloI : public Test::Hello
{
public:

    virtual void sayHello(const Ice::Current&);
};

class TestI : public Test::TestIntf
{
public:

    TestI(const Ice::ObjectAdapterPtr&, const Ice::ObjectAdapterPtr&, const ServerLocatorRegistryPtr&);

    virtual void shutdown(const Ice::Current&);
    virtual ::Test::HelloPrx getHello(const Ice::Current&);
    virtual ::Test::HelloPrx getReplicatedHello(const Ice::Current&);
    virtual void migrateHello(const Ice::Current&);

private:

    Ice::ObjectAdapterPtr _adapter1;
    Ice::ObjectAdapterPtr _adapter2;
    ServerLocatorRegistryPtr _registry;

};

#endif

#endif

==> zeroc-icee_1.2.0.orig.tar.gz: IceE-1.2.0/test/IceE/location/TestI.h <==
// **********************************************************************
//
// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
//
// This copy of Ice-E is licensed to you under the terms described in the
// ICEE_LICENSE file included in this distribution.
//
// **********************************************************************

#ifndef TEST_I_H
#define TEST_I_H

#include <IceE/Config.h>

#ifdef ICEE_HAS_LOCATOR

#include <Test.h>
#include <vector>
#include <ServerLocator.h>

class ServerManagerI : public Test::ServerManager
{
public:

    ServerManagerI(const Ice::ObjectAdapterPtr&, const ServerLocatorRegistryPtr&, 
		   const Ice::InitializationData&);
    
    virtual void startServer(const Ice::Current&);
    virtual void shutdown(const Ice::Current&);

private:

    Ice::ObjectAdapterPtr _adapter;
    ServerLocatorRegistryPtr _registry;
    Ice::InitializationData _initData;
    std::vector<Ice::CommunicatorPtr> _communicators;
};

class HelloI : public Test::Hello
{
public:

    virtual void sayHello(const Ice::Current&);
};

class TestI : public Test::TestIntf
{
public:

    TestI(const Ice::ObjectAdapterPtr&, const Ice::ObjectAdapterPtr&, const ServerLocatorRegistryPtr&);

    virtual void shutdown(const Ice::Current&);
    virtual ::Test::HelloPrx getHello(const Ice::Current&);
    virtual ::Test::HelloPrx getReplicatedHello(const Ice::Current&);
    virtual void migrateHello(const Ice::Current&);

private:

    Ice::ObjectAdapterPtr _adapter1;
    Ice::ObjectAdapterPtr _adapter2;
    ServerLocatorRegistryPtr _registry;

};

#endif

#endif
